==> apcu-4.0.8.tgz: apcu-4.0.8/php_apc.h <==
/*
  +----------------------------------------------------------------------+
  | APC                                                                  |
  +----------------------------------------------------------------------+
  | Copyright (c) 2006-2011 The PHP Group                                |
  +----------------------------------------------------------------------+
  | This source file is subject to version 3.01 of the PHP license,      |
  | that is bundled with this package in the file LICENSE, and is        |
  | available through the world-wide-web at the following url:           |
  | http://www.php.net/license/3_01.txt                                  |
  | If you did not receive a copy of the PHP license and are unable to   |
  | obtain it through the world-wide-web, please send a note to          |
  | license@php.net so we can mail you a copy immediately.               |
  +----------------------------------------------------------------------+
  | Authors: Daniel Cowgill <dcowgill@communityconnect.com>              |
  |          George Schlossnagle <george@omniti.com>                     |
  |          Rasmus Lerdorf <rasmus@php.net>                             |
  +----------------------------------------------------------------------+

   This software was contributed to PHP by Community Connect Inc. in 2002
   and revised in 2005 by Yahoo! Inc. to add support for PHP 5.1.
   Future revisions and derivatives of this source code must acknowledge
   Community Connect Inc. as the original contributor of this module by
   leaving this note intact in the source code.

   All other licensing and usage conditions are those of the PHP Group.

 */

/* $Id: php_apc.h 328953 2013-01-03 02:19:19Z rasmus $ */

#ifndef PHP_APC_H
#define PHP_APC_H

#include "apc_php.h"
#include "apc_globals.h"

#define PHP_APCU_VERSION "4.0.8"
#define PHP_APCU_EXTNAME "apcu"

extern zend_module_entry apcu_module_entry;
#define apcu_module_ptr &apcu_module_entry

#define phpext_apcu_ptr apcu_module_ptr

#endif /* PHP_APC_H */

/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * End:
 * vim>600: expandtab sw=4 ts=4 sts=4 fdm=marker
 * vim<600: expandtab sw=4 ts=4 sts=4
 */

==> apcu-5.1.10.tgz: apcu-5.1.10/php_apc.h <==
/*
  +----------------------------------------------------------------------+
  | APC                                                                  |
  +----------------------------------------------------------------------+
  | Copyright (c) 2006-2011 The PHP Group                                |
  +----------------------------------------------------------------------+
  | This source file is subject to version 3.01 of the PHP license,      |
  | that is bundled with this package in the file LICENSE, and is        |
  | available through the world-wide-web at the following url:           |
  | http://www.php.net/license/3_01.txt                                  |
  | If you did not receive a copy of the PHP license and are unable to   |
  | obtain it through the world-wide-web, please send a note to          |
  | license@php.net so we can mail you a copy immediately.               |
  +----------------------------------------------------------------------+
  | Authors: Daniel Cowgill <dcowgill@communityconnect.com>              |
  |          George Schlossnagle <george@omniti.com>                     |
  |          Rasmus Lerdorf <rasmus@php.net>                             |
  +----------------------------------------------------------------------+

   This software was contributed to PHP by Community Connect Inc. in 2002
   and revised in 2005 by Yahoo! Inc. to add support for PHP 5.1.
   Future revisions and derivatives of this source code must acknowledge
   Community Connect Inc. as the original contributor of this module by
   leaving this note intact in the source code.

   All other licensing and usage conditions are those of the PHP Group.

 */

/* $Id: php_apc.h 328953 2013-01-03 02:19:19Z rasmus $ */

#ifndef PHP_APCU_H
#define PHP_APCU_H

#include "apc.h"
#include "apc_globals.h"

#define PHP_APCU_VERSION "5.1.10"
#define PHP_APCU_EXTNAME "apcu"

PHP_APCU_API PHP_FUNCTION(apcu_add);
PHP_APCU_API PHP_FUNCTION(apcu_delete);
PHP_APCU_API PHP_FUNCTION(apcu_exists);
PHP_APCU_API PHP_FUNCTION(apcu_fetch);
PHP_APCU_API PHP_FUNCTION(apcu_store);
PHP_APCU_API PHP_FUNCTION(apcu_inc);
PHP_APCU_API PHP_FUNCTION(apcu_dec);
PHP_APCU_API PHP_FUNCTION(apcu_cas);
PHP_APCU_API PHP_FUNCTION(apcu_enabled);
PHP_APCU_API PHP_FUNCTION(apcu_sma_info);
PHP_APCU_API PHP_FUNCTION(apcu_entry);

PHP_APCU_API zend_bool apc_is_enabled(void);

extern zend_module_entry apcu_module_entry;
#define apcu_module_ptr &apcu_module_entry

#define phpext_apcu_ptr apcu_module_ptr

#if defined(ZTS) && defined(COMPILE_DL_APCU)
ZEND_TSRMLS_CACHE_EXTERN();
#endif

#endif /* PHP_APC_H */

/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * End:
 * vim>600: expandtab sw=4 ts=4 sts=4 fdm=marker
 * vim<600: expandtab sw=4 ts=4 sts=4
 */
